import{h as a,u as c,b as n,c as u}from"./index-B51TLSWN.js";const h={__name:"index",setup(p){const e=a(),t=c(),{params:o,query:r}=e,{path:s}=o;return t.replace({path:"/"+s,query:r}),(_,m)=>(n(),u("div"))}};export{h as default};
