.icon-ul[data-v-4bd3554f]{margin:0;padding:0;font-size:0}.icon-ul li[data-v-4bd3554f]{list-style-type:none;text-align:center;font-size:14px;display:inline-flex;width:16.66%;box-sizing:border-box;height:108px;padding:6px;cursor:pointer;overflow:hidden;align-items:center;justify-content:center}.icon-ul li[data-v-4bd3554f]:hover{background:#f2f2f2}.icon-ul li.active-item[data-v-4bd3554f]{background:#e1f3fb;color:#7a6df0}.icon-ul li i[data-v-4bd3554f]{font-size:30px;line-height:50px;margin-bottom:10px}.icon-dialog[data-v-4bd3554f] .el-dialog{border-radius:8px;margin-bottom:0;margin-top:4vh!important;display:flex;flex-direction:column;max-height:92vh;overflow:hidden;box-sizing:border-box}.icon-dialog[data-v-4bd3554f] .el-dialog .el-dialog__header{padding-top:14px}.icon-dialog[data-v-4bd3554f] .el-dialog .el-dialog__body{margin:0 20px 20px;padding:0;overflow:auto}
