import{_ as B,a as c,ad as D,ai as M,w as O,k as d,b as t,c as u,l as r,m,d as p,F as z,e as L,f,M as N,v as S,a6 as E,t as F,q as U,J as j,ae as q}from"./index-B51TLSWN.js";const J={class:"icon-dialog"},P={class:"icon-ul"},R=["onClick"],T={__name:"IconsDialog",props:{modelValue:{},modelModifiers:{}},emits:q(["select"],["update:modelValue"]),setup(v,{emit:V}){const s=c([]),n=[],a=c(""),_=c(""),k=V,i=D(v,"modelValue");for(const[e]of Object.entries(M))s.value.push(e),n.push(e);function g(){}function x(){}function C(e){_.value=e,k("select",e),i.value=!1}return O(a,e=>{e?s.value=n.filter(l=>l.indexOf(e)>-1):s.value=n}),(e,l)=>{const h=d("el-input"),y=d("el-icon"),b=d("el-dialog");return t(),u("div",J,[r(b,{modelValue:i.value,"onUpdate:modelValue":l[1]||(l[1]=o=>i.value=o),width:"980px","close-on-click-modal":!1,"modal-append-to-body":!1,onOpen:g,onClose:x},{header:m(({close:o,titleId:w,titleClass:$})=>[l[2]||(l[2]=U(" 选择图标 ",-1)),r(h,{modelValue:f(a),"onUpdate:modelValue":l[0]||(l[0]=I=>j(a)?a.value=I:null),size:"small",style:{width:"260px"},placeholder:"请输入图标名称","prefix-icon":"Search",clearable:""},null,8,["modelValue"])]),default:m(()=>[p("ul",P,[(t(!0),u(z,null,L(f(s),o=>(t(),u("li",{key:o,class:N(f(_)===o?"active-item":""),onClick:w=>C(o)},[p("div",null,[r(y,{size:30},{default:m(()=>[(t(),S(E(o)))]),_:2},1024),p("div",null,F(o),1)])],10,R))),128))])]),_:1},8,["modelValue"])])}}},G=B(T,[["__scopeId","data-v-4bd3554f"]]);export{G as default};
