.right-board[data-v-90d11c9d]{width:350px;position:absolute;right:0;top:0;padding-top:3px}.right-board[data-v-90d11c9d] .el-tabs__header{margin:0}.right-board[data-v-90d11c9d] .el-input-group__append .el-button{display:inline-flex}.right-board .field-box[data-v-90d11c9d]{position:relative;height:calc(100vh - 132px);box-sizing:border-box;overflow:hidden}.right-board .el-scrollbar[data-v-90d11c9d]{height:100%}.right-board .el-scrollbar[data-v-90d11c9d] .el-scrollbar__view{padding:30px 20px}.reg-item[data-v-90d11c9d]{padding:12px 6px;background:var(--el-border-color-extra-light);position:relative;border-radius:4px}.reg-item .close-btn[data-v-90d11c9d]{position:absolute;right:-6px;top:-6px;display:flex;align-items:center;justify-content:center;width:16px;height:16px;line-height:16px;background:#0003;border-radius:50%;color:#fff;z-index:1;cursor:pointer;font-size:12px}.select-item[data-v-90d11c9d]{display:flex;border:1px dashed #fff;box-sizing:border-box}.select-item .close-btn[data-v-90d11c9d]{cursor:pointer;color:#f56c6c}.select-item .el-input+.el-input[data-v-90d11c9d]{margin-left:4px}.select-item+.select-item[data-v-90d11c9d]{margin-top:4px}.select-item.sortable-chosen[data-v-90d11c9d]{border:1px dashed #409eff}.select-line-icon[data-v-90d11c9d]{line-height:32px;font-size:22px;padding:0 4px;color:#777}.option-drag[data-v-90d11c9d]{cursor:move}.time-range .el-date-editor[data-v-90d11c9d]{width:227px}.time-range[data-v-90d11c9d] .el-icon-time{display:none}.document-link[data-v-90d11c9d]{position:absolute;display:flex;width:26px;height:26px;top:0;left:0;cursor:pointer;background:#409eff;z-index:1;border-radius:0 0 6px;justify-content:center;align-items:center;color:#fff;font-size:18px}.node-label[data-v-90d11c9d]{font-size:14px}.node-icon[data-v-90d11c9d]{color:#bebfc3}.custom-tree-node[data-v-90d11c9d]{flex:1;display:flex;align-items:center;justify-content:space-between;font-size:14px;padding-right:8px}
