.social-console[data-v-45aabb1a]{display:flex;flex-direction:column;gap:16px}.hero[data-v-45aabb1a]{display:flex;justify-content:space-between;gap:24px;padding:28px;border-radius:20px;color:#fff;background:radial-gradient(circle at top left,rgba(255,209,187,.24),transparent 26%),linear-gradient(135deg,#9d3d2f,#672e39 42%,#22283d)}.eyebrow[data-v-45aabb1a]{margin:0 0 10px;font-size:12px;letter-spacing:.22em;text-transform:uppercase;opacity:.7}.hero-copy h1[data-v-45aabb1a]{margin:0;font-size:32px}.hero-text[data-v-45aabb1a]{max-width:720px;margin:14px 0 0;line-height:1.8;color:#ffffffd6}.hero-side[data-v-45aabb1a]{display:flex;flex-direction:column;align-items:flex-end;gap:10px}.phase-badge[data-v-45aabb1a],.env-chip[data-v-45aabb1a]{display:inline-flex;align-items:center;justify-content:center;min-height:38px;padding:0 14px;border-radius:999px;background:#ffffff1f}.metric-card[data-v-45aabb1a],.panel[data-v-45aabb1a]{border-radius:18px}.metric-title[data-v-45aabb1a]{color:#7f6771;font-size:13px}.metric-value[data-v-45aabb1a]{margin-top:8px;font-size:28px;font-weight:700;color:#4f2332}.metric-desc[data-v-45aabb1a]{margin-top:6px;color:#7e7980;line-height:1.6}.panel-row[data-v-45aabb1a]{margin-top:2px}.panel-title[data-v-45aabb1a]{font-size:16px;font-weight:700;color:#4f2332}.module-list[data-v-45aabb1a],.todo-list[data-v-45aabb1a]{display:flex;flex-direction:column;gap:14px}.module-item[data-v-45aabb1a],.todo-item[data-v-45aabb1a]{display:flex;justify-content:space-between;gap:16px;padding:16px 18px;border-radius:16px;background:#faf6f7}.module-item p[data-v-45aabb1a]{margin:8px 0 0;color:#7b6d74;line-height:1.7}.module-meta[data-v-45aabb1a]{display:flex;flex-direction:column;gap:8px}.todo-item[data-v-45aabb1a]{font-weight:600;color:#5a3742}@media(max-width:960px){.hero[data-v-45aabb1a],.module-item[data-v-45aabb1a]{flex-direction:column}.hero-side[data-v-45aabb1a]{align-items:flex-start}}
