import{_ as o,j as l,k as c,b as _,c as n,d as t,s as d,t as r,f as p,l as m,m as u,q as f}from"./index-B51TLSWN.js";const v="/static/png/404-N4aRkdWY.png",a="/static/png/404_cloud-CPexjtDj.png",g={class:"wscn-http404-container"},h={class:"wscn-http404"},x={class:"bullshit"},b={class:"bullshit__headline"},k={__name:"404",setup(N){let i=l(()=>"找不到网页！");return(V,s)=>{const e=c("router-link");return _(),n("div",g,[t("div",h,[s[3]||(s[3]=d('<div class="pic-404" data-v-aa824f31><img class="pic-404__parent" src="'+v+'" alt="404" data-v-aa824f31><img class="pic-404__child left" src="'+a+'" alt="404" data-v-aa824f31><img class="pic-404__child mid" src="'+a+'" alt="404" data-v-aa824f31><img class="pic-404__child right" src="'+a+'" alt="404" data-v-aa824f31></div>',1)),t("div",x,[s[1]||(s[1]=t("div",{class:"bullshit__oops"}," 404错误! ",-1)),t("div",b,r(p(i)),1),s[2]||(s[2]=t("div",{class:"bullshit__info"}," 对不起，您正在寻找的页面不存在。尝试检查URL的错误，然后按浏览器上的刷新按钮或尝试在我们的应用程序中找到其他内容。 ",-1)),m(e,{to:"/index",class:"bullshit__return-home"},{default:u(()=>[...s[0]||(s[0]=[f(" 返回首页 ",-1)])]),_:1})])])])}}},w=o(k,[["__scopeId","data-v-aa824f31"]]);export{w as default};
