import{C as e}from"./index-B51TLSWN.js";function s(t){return e({url:"/system/dict/type/list",method:"get",params:t})}function u(t){return e({url:"/system/dict/type/"+t,method:"get"})}function d(t){return e({url:"/system/dict/type",method:"post",data:t})}function n(t){return e({url:"/system/dict/type",method:"put",data:t})}function o(t){return e({url:"/system/dict/type/"+t,method:"delete"})}function i(){return e({url:"/system/dict/type/refreshCache",method:"delete"})}function p(){return e({url:"/system/dict/type/optionselect",method:"get"})}export{d as a,o as d,u as g,s as l,p as o,i as r,n as u};
