.icon-body[data-v-83021115]{width:100%;padding:10px}.icon-body .icon-search[data-v-83021115]{position:relative;margin-bottom:5px}.icon-body .icon-list[data-v-83021115]{height:200px;overflow:auto}.icon-body .icon-list .list-container[data-v-83021115]{display:flex;flex-wrap:wrap}.icon-body .icon-list .list-container .icon-item-wrapper[data-v-83021115]{width:33.3333333333%;height:25px;line-height:25px;cursor:pointer;display:flex}.icon-body .icon-list .list-container .icon-item-wrapper .icon-item[data-v-83021115]{display:flex;max-width:100%;height:100%;padding:0 5px}.icon-body .icon-list .list-container .icon-item-wrapper .icon-item[data-v-83021115]:hover{background:#ececec;border-radius:5px}.icon-body .icon-list .list-container .icon-item-wrapper .icon-item .icon[data-v-83021115]{flex-shrink:0}.icon-body .icon-list .list-container .icon-item-wrapper .icon-item span[data-v-83021115]{display:inline-block;vertical-align:-.15em;fill:currentColor;padding-left:2px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.icon-body .icon-list .list-container .icon-item-wrapper .icon-item.active[data-v-83021115]{background:#ececec;border-radius:5px}
