.register[data-v-fe894776]{display:flex;justify-content:center;align-items:center;height:100%;background-image:url(/static/jpg/login-background-Yn3y1TP_.jpg);background-size:cover}.title[data-v-fe894776]{margin:0 auto 30px;text-align:center;color:#707070}.register-form[data-v-fe894776]{border-radius:6px;background:#fff;width:400px;padding:25px 25px 5px}.register-form .el-input[data-v-fe894776],.register-form .el-input input[data-v-fe894776]{height:40px}.register-form .input-icon[data-v-fe894776]{height:39px;width:14px;margin-left:0}.register-tip[data-v-fe894776]{font-size:13px;text-align:center;color:#bfbfbf}.register-code[data-v-fe894776]{width:33%;height:40px;float:right}.register-code img[data-v-fe894776]{cursor:pointer;vertical-align:middle}.el-register-footer[data-v-fe894776]{height:40px;line-height:40px;position:fixed;bottom:0;width:100%;text-align:center;color:#fff;font-family:Arial;font-size:12px;letter-spacing:1px}.register-code-img[data-v-fe894776]{height:40px;padding-left:12px}
