import{C as t}from"./index-B51TLSWN.js";function n(e){return t({url:"/system/menu/list",method:"get",params:e})}function r(e){return t({url:"/system/menu/"+e,method:"get"})}function s(){return t({url:"/system/menu/treeselect",method:"get"})}function m(e){return t({url:"/system/menu/roleMenuTreeselect/"+e,method:"get"})}function o(e){return t({url:"/system/menu",method:"post",data:e})}function l(e){return t({url:"/system/menu",method:"put",data:e})}function a(e){return t({url:"/system/menu/"+e,method:"delete"})}export{o as a,a as d,r as g,n as l,m as r,s as t,l as u};
