import{_ as p,B as f,a as m,k as n,b as k,c as g,l as o,m as s,q as a,d as e,f as x}from"./index-B51TLSWN.js";const b="/static/gif/401-HGF6Q5qM.gif",h={class:"errPage-container"},w={class:"list-unstyled"},B={class:"link-type"},y=["src"],C={__name:"401",setup(G){let{proxy:r}=f();const c=m(b+"?"+ +new Date);function u(){r.$route.query.noGoBack?r.$router.push({path:"/"}):r.$router.go(-1)}return(q,t)=>{const _=n("el-button"),i=n("router-link"),l=n("el-col"),d=n("el-row");return k(),g("div",h,[o(_,{icon:"arrow-left",class:"pan-back-btn",onClick:u},{default:s(()=>[...t[0]||(t[0]=[a(" 返回 ",-1)])]),_:1}),o(d,null,{default:s(()=>[o(l,{span:12},{default:s(()=>[t[2]||(t[2]=e("h1",{class:"text-jumbo text-ginormous"}," 401错误! ",-1)),t[3]||(t[3]=e("h2",null,"您没有访问权限！",-1)),t[4]||(t[4]=e("h6",null,"对不起，您没有访问权限，请不要进行非法操作！您可以返回主页面",-1)),e("ul",w,[e("li",B,[o(i,{to:"/"},{default:s(()=>[...t[1]||(t[1]=[a(" 回首页 ",-1)])]),_:1})])])]),_:1}),o(l,{span:12},{default:s(()=>[e("img",{src:x(c),width:"313",height:"428",alt:"Girl has dropped her ice cream."},null,8,y)]),_:1})]),_:1})])}}},I=p(C,[["__scopeId","data-v-014d618d"]]);export{I as default};
