import{C as e}from"./index-B51TLSWN.js";function t(){return e({url:"/system/social/public/landing",method:"get"})}function o(){return e({url:"/system/social/admin/overview",method:"get"})}function r(){return e({url:"/system/social/public/profiles",method:"get"})}export{r as a,o as b,t as g};
