.vue-cropper[data-v-69939069]{position:relative;width:100%;height:100%;box-sizing:border-box;user-select:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;direction:ltr;touch-action:none;text-align:left;background-image:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAQAQMAAAAlPW0iAAAAA3NCSVQICAjb4U/gAAAABlBMVEXMzMz////TjRV2AAAACXBIWXMAAArrAAAK6wGCiw1aAAAAHHRFWHRTb2Z0d2FyZQBBZG9iZSBGaXJld29ya3MgQ1M26LyyjAAAABFJREFUCJlj+M/AgBVhF/0PAH6/D/HkDxOGAAAAAElFTkSuQmCC)}.cropper-box[data-v-69939069],.cropper-box-canvas[data-v-69939069],.cropper-drag-box[data-v-69939069],.cropper-crop-box[data-v-69939069],.cropper-face[data-v-69939069]{position:absolute;top:0;right:0;bottom:0;left:0;-webkit-user-select:none;user-select:none}.cropper-box-canvas img[data-v-69939069]{position:relative;text-align:left;-webkit-user-select:none;user-select:none;transform:none;max-width:none;max-height:none}.cropper-box[data-v-69939069]{overflow:hidden}.cropper-move[data-v-69939069]{cursor:move}.cropper-crop[data-v-69939069]{cursor:crosshair}.cropper-modal[data-v-69939069]{background:#00000080}.cropper-view-box[data-v-69939069]{display:block;overflow:hidden;width:100%;height:100%;outline:1px solid #39f;outline-color:#3399ffbf;-webkit-user-select:none;user-select:none}.cropper-view-box img[data-v-69939069]{-webkit-user-select:none;user-select:none;text-align:left;max-width:none;max-height:none}.cropper-face[data-v-69939069]{top:0;left:0;background-color:#fff;opacity:.1}.crop-info[data-v-69939069]{position:absolute;left:0;min-width:65px;text-align:center;color:#fff;line-height:20px;background-color:#000c;font-size:12px}.crop-line[data-v-69939069]{position:absolute;display:block;width:100%;height:100%;opacity:.1}.line-w[data-v-69939069]{top:-3px;left:0;height:5px;cursor:n-resize}.line-a[data-v-69939069]{top:0;left:-3px;width:5px;cursor:w-resize}.line-s[data-v-69939069]{bottom:-3px;left:0;height:5px;cursor:s-resize}.line-d[data-v-69939069]{top:0;right:-3px;width:5px;cursor:e-resize}.crop-point[data-v-69939069]{position:absolute;width:8px;height:8px;opacity:.75;background-color:#39f;border-radius:100%}.point1[data-v-69939069]{top:-4px;left:-4px;cursor:nw-resize}.point2[data-v-69939069]{top:-5px;left:50%;margin-left:-3px;cursor:n-resize}.point3[data-v-69939069]{top:-4px;right:-4px;cursor:ne-resize}.point4[data-v-69939069]{top:50%;left:-4px;margin-top:-3px;cursor:w-resize}.point5[data-v-69939069]{top:50%;right:-4px;margin-top:-3px;cursor:e-resize}.point6[data-v-69939069]{bottom:-5px;left:-4px;cursor:sw-resize}.point7[data-v-69939069]{bottom:-5px;left:50%;margin-left:-3px;cursor:s-resize}.point8[data-v-69939069]{bottom:-5px;right:-4px;cursor:se-resize}@media screen and (max-width:500px){.crop-point[data-v-69939069]{position:absolute;width:20px;height:20px;opacity:.45;background-color:#39f;border-radius:100%}.point1[data-v-69939069]{top:-10px;left:-10px}.point2[data-v-69939069],.point4[data-v-69939069],.point5[data-v-69939069],.point7[data-v-69939069]{display:none}.point3[data-v-69939069]{top:-10px;right:-10px}.point4[data-v-69939069]{top:0;left:0}.point6[data-v-69939069]{bottom:-10px;left:-10px}.point8[data-v-69939069]{bottom:-10px;right:-10px}}.user-info-head[data-v-e3e9a521]{position:relative;display:inline-block;height:120px}.user-info-head[data-v-e3e9a521]:hover:after{content:"+";position:absolute;left:0;right:0;top:0;bottom:0;color:#eee;background:#00000080;font-size:24px;font-style:normal;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;cursor:pointer;line-height:110px;border-radius:50%}
