import{C as t}from"./index-B51TLSWN.js";function l(e){return t({url:"/system/role/list",method:"get",params:e})}function u(e){return t({url:"/system/role/"+e,method:"get"})}function o(e){return t({url:"/system/role",method:"post",data:e})}function n(e){return t({url:"/system/role",method:"put",data:e})}function d(e){return t({url:"/system/role/dataScope",method:"put",data:e})}function c(e,r){return t({url:"/system/role/changeStatus",method:"put",data:{roleId:e,status:r}})}function m(e){return t({url:"/system/role/"+e,method:"delete"})}function h(e){return t({url:"/system/role/authUser/allocatedList",method:"get",params:e})}function i(e){return t({url:"/system/role/authUser/unallocatedList",method:"get",params:e})}function p(e){return t({url:"/system/role/authUser/cancel",method:"put",data:e})}function f(e){return t({url:"/system/role/authUser/cancelAll",method:"put",params:e})}function y(e){return t({url:"/system/role/authUser/selectAll",method:"put",params:e})}function U(e){return t({url:"/system/role/deptTree/"+e,method:"get"})}export{h as a,f as b,p as c,m as d,c as e,o as f,u as g,d as h,U as i,i as j,y as k,l,n as u};
