.login[data-v-a33678a6]{display:flex;justify-content:center;align-items:center;height:100%;background-image:url(/static/jpg/login-background-Yn3y1TP_.jpg);background-size:cover}.title[data-v-a33678a6]{margin:0 auto 30px;text-align:center;color:#707070}.login-form[data-v-a33678a6]{border-radius:6px;background:#fff;width:400px;padding:25px 25px 5px;z-index:1}.login-form .el-input[data-v-a33678a6],.login-form .el-input input[data-v-a33678a6]{height:40px}.login-form .input-icon[data-v-a33678a6]{height:39px;width:14px;margin-left:0}.login-tip[data-v-a33678a6]{font-size:13px;text-align:center;color:#bfbfbf}.login-code[data-v-a33678a6]{width:33%;height:40px;float:right}.login-code img[data-v-a33678a6]{cursor:pointer;vertical-align:middle}.el-login-footer[data-v-a33678a6]{height:40px;line-height:40px;position:fixed;bottom:0;width:100%;text-align:center;color:#fff;font-family:Arial;font-size:12px;letter-spacing:1px}.login-code-img[data-v-a33678a6]{height:40px;padding-left:12px}
